@@ -10,13 +10,17 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: arch.ml,v 1.9 2002/07/22 16:37:46 doligez Exp $ *)
+(* $Id: arch.ml,v 1.10 2002/11/29 15:03:36 xleroy Exp $ *)
 
 (* Specific operations for the Alpha processor *)
 
 open Misc
 open Format
 
+(* Machine-specific command-line options *)
+
+let command_line_options = []
+
 (* Addressing modes *)
 
 type addressing_mode =
