@@ -10,13 +10,17 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: asmlink.mli,v 1.7 2000/04/21 08:10:28 weis Exp $ *)
+(* $Id: asmlink.mli,v 1.11 2006/10/17 12:33:58 xleroy Exp $ *)
 
 (* Link a set of .cmx/.o files and produce an executable *)
 
 open Format
 
-val link: formatter -> string list -> unit
+val link: formatter -> string list -> string -> unit
+
+val check_consistency: string -> Compilenv.unit_infos -> Digest.t -> unit
+val extract_crc_interfaces: unit -> (string * Digest.t) list
+val extract_crc_implementations: unit -> (string * Digest.t) list
 
 type error =
     File_not_found of string
@@ -26,6 +30,8 @@ type error =
   | Inconsistent_implementation of string * string * string
   | Assembler_error of string
   | Linking_error
+  | Multiple_definition of string * string * string
+  | Missing_cmx of string * string
 
 exception Error of error
 
