@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: clambda.ml,v 1.16.8.2 2005/12/11 10:21:12 xleroy Exp $ *)
+(* $Id: clambda.ml,v 1.17 2007/01/29 12:10:50 xleroy Exp $ *)
 
 (* A variant of the "lambda" code with direct / indirect calls explicit
    and closures explicit too *)
@@ -23,14 +23,14 @@ type function_label = string
 type ulambda =
     Uvar of Ident.t
   | Uconst of structured_constant
-  | Udirect_apply of function_label * ulambda list
-  | Ugeneric_apply of ulambda * ulambda list
+  | Udirect_apply of function_label * ulambda list * Debuginfo.t
+  | Ugeneric_apply of ulambda * ulambda list * Debuginfo.t
   | Uclosure of (function_label * int * Ident.t list * ulambda) list
               * ulambda list
   | Uoffset of ulambda * int
   | Ulet of Ident.t * ulambda * ulambda
   | Uletrec of (Ident.t * ulambda) list * ulambda
-  | Uprim of primitive * ulambda list
+  | Uprim of primitive * ulambda list * Debuginfo.t
   | Uswitch of ulambda * ulambda_switch
   | Ustaticfail of int * ulambda list
   | Ucatch of int * Ident.t list * ulambda * ulambda
@@ -40,7 +40,7 @@ type ulambda =
   | Uwhile of ulambda * ulambda
   | Ufor of Ident.t * ulambda * ulambda * direction_flag * ulambda
   | Uassign of Ident.t * ulambda
-  | Usend of meth_kind * ulambda * ulambda * ulambda list
+  | Usend of meth_kind * ulambda * ulambda * ulambda list * Debuginfo.t
 
 and ulambda_switch =
   { us_index_consts: int array;
