@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: selection.ml,v 1.13 2003/02/25 15:50:13 xleroy Exp $ *)
+(* $Id: selection.ml,v 1.15 2007/01/29 12:10:50 xleroy Exp $ *)
 
 (* Instruction selection for the Intel x86 *)
 
@@ -88,7 +88,7 @@ let rec float_needs = function
       let n1 = float_needs arg1 in
       let n2 = float_needs arg2 in
       if n1 = n2 then 1 + n1 else if n1 > n2 then n1 else n2
-  | Cop(Cextcall(fn, ty_res, alloc), args)
+  | Cop(Cextcall(fn, ty_res, alloc, dbg), args)
     when !fast_math && List.mem fn inline_float_ops ->
       begin match args with
         [arg] -> float_needs arg
@@ -159,6 +159,15 @@ inherit Selectgen.selector_generic as super
 
 method is_immediate (n : int) = true
 
+method is_simple_expr e =
+  match e with
+  | Cop(Cextcall(fn, _, alloc, _), args)
+    when !fast_math && List.mem fn inline_float_ops ->
+      (* inlined float ops are simple if their arguments are *)
+      List.for_all self#is_simple_expr args
+  | _ ->
+      super#is_simple_expr e
+
 method select_addressing exp =
   match select_addr exp with
     (Asymbol s, d) ->
@@ -230,7 +239,7 @@ method select_operation op args =
           super#select_operation op args
       end
   (* Recognize inlined floating point operations *)
-  | Cextcall(fn, ty_res, false)
+  | Cextcall(fn, ty_res, false, dbg)
     when !fast_math && List.mem fn inline_float_ops ->
       (Ispecific(Ifloatspecial fn), args)
   (* Default *)
@@ -260,18 +269,21 @@ method select_floatarith regular_op reversed_op mem_op mem_rev_op args =
 
 (* Deal with register constraints *)
 
-method insert_op op rs rd =
+method insert_op_debug op dbg rs rd =
   try
     let (rsrc, rdst, move_res) = pseudoregs_for_operation op rs rd in
     self#insert_moves rs rsrc;
-    self#insert (Iop op) rsrc rdst;
+    self#insert_debug (Iop op) dbg rsrc rdst;
     if move_res then begin
       self#insert_moves rdst rd;
       rd
     end else
       rdst
   with Use_default ->
-    super#insert_op op rs rd
+    super#insert_op_debug op dbg rs rd
+
+method insert_op op rs rd =
+  self#insert_op_debug op Debuginfo.none rs rd
 
 (* Selection of push instructions for external calls *)
 
@@ -291,18 +303,23 @@ method select_push exp =
   | _ -> (Ispecific(Ipush), exp)
 
 method emit_extcall_args env args =
+  let rec size_pushes = function
+  | [] -> 0
+  | e :: el -> Selectgen.size_expr env e + size_pushes el in
+  let sz1 = size_pushes args in
+  let sz2 = Misc.align sz1 stack_alignment in
   let rec emit_pushes = function
-    [] -> 0
+  | [] ->
+      if sz2 > sz1 then 
+        self#insert (Iop (Istackoffset (sz2 - sz1))) [||] [||]
   | e :: el ->
-      let ofs = emit_pushes el in
+      emit_pushes el;
       let (op, arg) = self#select_push e in
-      begin match self#emit_expr env arg with
-        None -> ofs
-      | Some r ->
-          self#insert (Iop op) r [||];
-          ofs + Selectgen.size_expr env e
-      end
-  in ([||], emit_pushes args)
+      match self#emit_expr env arg with
+      | None -> ()
+      | Some r -> self#insert (Iop op) r [||] in
+  emit_pushes args;
+  ([||], sz2)
 
 end
 
