@@ -10,13 +10,17 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: arch.ml,v 1.4 2002/07/22 16:37:51 doligez Exp $ *)
+(* $Id: arch.ml,v 1.5 2002/11/29 15:03:36 xleroy Exp $ *)
 
 (* Specific operations for the IA64 processor *)
 
 open Misc
 open Format
 
+(* Machine-specific command-line options *)
+
+let command_line_options = []
+
 (* Addressing modes -- only one! (register with no displacement) *)
 
 type addressing_mode = Iindexed
