@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: proc.ml,v 1.4 1999/11/17 18:56:45 xleroy Exp $ *)
+(* $Id: proc.ml,v 1.6 2002/07/22 16:37:52 doligez Exp $ *)
 
 (* Description of the Mips processor *)
 
@@ -205,5 +205,7 @@ let contains_calls = ref false
 let asm_command = "as -n32 -O2 -nocpp -g0 -o "
 
 let assemble_file infile outfile =
-  Ccomp.command (asm_command ^ outfile ^ " " ^ infile)
+  Ccomp.command (asm_command ^ Filename.quote outfile ^ " " ^ Filename.quote infile)
 
+open Clflags;;
+open Config;;
