@@ -10,20 +10,22 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: printmach.mli,v 1.5 1999/11/17 18:56:35 xleroy Exp $ *)
+(* $Id: printmach.mli,v 1.6 2000/04/21 08:10:37 weis Exp $ *)
 
 (* Pretty-printing of pseudo machine code *)
 
-val reg: Reg.t -> unit
-val regs: Reg.t array -> unit
-val regset: Reg.Set.t -> unit
-val regsetaddr: Reg.Set.t -> unit
-val operation: Mach.operation -> Reg.t array -> Reg.t array -> unit
-val test: Mach.test -> Reg.t array -> unit
-val instr: Mach.instruction -> unit
-val fundecl: Mach.fundecl -> unit
-val phase: string -> Mach.fundecl -> unit
-val interferences: unit -> unit
-val preferences: unit -> unit
+open Format
+
+val reg: formatter -> Reg.t -> unit
+val regs: formatter -> Reg.t array -> unit
+val regset: formatter -> Reg.Set.t -> unit
+val regsetaddr: formatter -> Reg.Set.t -> unit
+val operation: Mach.operation -> Reg.t array -> formatter -> Reg.t array -> unit
+val test: Mach.test -> formatter -> Reg.t array -> unit
+val instr: formatter -> Mach.instruction -> unit
+val fundecl: formatter -> Mach.fundecl -> unit
+val phase: string -> formatter -> Mach.fundecl -> unit
+val interferences: formatter -> unit -> unit
+val preferences: formatter -> unit -> unit
 
 val print_live: bool ref
