@@ -11,13 +11,14 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: startup.c,v 1.30.4.3 2005/03/16 12:05:28 doligez Exp $ */
+/* $Id: startup.c,v 1.33 2007/01/29 12:10:52 xleroy Exp $ */
 
 /* Start-up code */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include "callback.h"
+#include "backtrace.h"
 #include "custom.h"
 #include "fail.h"
 #include "gc.h"
@@ -64,12 +65,12 @@ static void init_atoms(void)
 
 /* Configuration parameters and flags */
 
-static unsigned long percent_free_init = Percent_free_def;
-static unsigned long max_percent_free_init = Max_percent_free_def;
-static unsigned long minor_heap_init = Minor_heap_def;
-static unsigned long heap_chunk_init = Heap_chunk_def;
-static unsigned long heap_size_init = Init_heap_def;
-static unsigned long max_stack_init = Max_stack_def;
+static uintnat percent_free_init = Percent_free_def;
+static uintnat max_percent_free_init = Max_percent_free_def;
+static uintnat minor_heap_init = Minor_heap_def;
+static uintnat heap_chunk_init = Heap_chunk_def;
+static uintnat heap_size_init = Init_heap_def;
+static uintnat max_stack_init = Max_stack_def;
 
 /* Parse the CAMLRUNPARAM variable */
 /* The option letter for each runtime option is the first letter of the
@@ -80,14 +81,18 @@ static unsigned long max_stack_init = Max_stack_def;
 
 /* If you change these functions, see also their copy in byterun/startup.c */
 
-static void scanmult (char *opt, long unsigned int *var)
+static void scanmult (char *opt, uintnat *var)
 {
   char mult = ' ';
-  sscanf (opt, "=%lu%c", var, &mult);
-  sscanf (opt, "=0x%lx%c", var, &mult);
-  if (mult == 'k') *var = *var * 1024;
-  if (mult == 'M') *var = *var * (1024 * 1024);
-  if (mult == 'G') *var = *var * (1024 * 1024 * 1024);
+  int val;
+  sscanf (opt, "=%u%c", &val, &mult);
+  sscanf (opt, "=0x%x%c", &val, &mult);
+  switch (mult) {
+  case 'k':   *var = (uintnat) val * 1024; break;
+  case 'M':   *var = (uintnat) val * 1024 * 1024; break;
+  case 'G':   *var = (uintnat) val * 1024 * 1024 * 1024; break;
+  default:    *var = (uintnat) val; break;
+  }
 }
 
 static void parse_camlrunparam(void)
@@ -106,6 +111,7 @@ static void parse_camlrunparam(void)
       case 'o': scanmult (opt, &percent_free_init); break;
       case 'O': scanmult (opt, &max_percent_free_init); break;
       case 'v': scanmult (opt, &caml_verb_gc); break;
+      case 'b': caml_init_backtrace(); break;
       case 'p': caml_parser_trace = 1; break;
       }
     }
