@@ -11,24 +11,25 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: freelist.h,v 1.8 2001/12/07 13:39:27 xleroy Exp $ */
+/* $Id: freelist.h,v 1.12.20.1 2008/02/12 21:26:29 doligez Exp $ */
 
 /* Free lists of heap blocks. */
 
-#ifndef _freelist_
-#define _freelist_
+#ifndef CAML_FREELIST_H
+#define CAML_FREELIST_H
 
 
 #include "misc.h"
 #include "mlvalues.h"
 
-extern asize_t fl_cur_size;
+extern asize_t caml_fl_cur_size;     /* size in words */
 
-char *fl_allocate (mlsize_t);
-void fl_init_merge (void);
-void fl_reset (void);
-char *fl_merge_block (char *);
-void fl_add_block (char *);
+char *caml_fl_allocate (mlsize_t);
+void caml_fl_init_merge (void);
+void caml_fl_reset (void);
+char *caml_fl_merge_block (char *);
+void caml_fl_add_blocks (char *);
+void caml_make_free_blocks (value *, mlsize_t, int);
 
 
-#endif /* _freelist_ */
+#endif /* CAML_FREELIST_H */
