@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: ints.c,v 1.50 2006/05/05 13:50:45 xleroy Exp $ */
+/* $Id: ints.c,v 1.50.6.1 2007/10/25 11:39:45 xleroy Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -551,15 +551,21 @@ CAMLprim value caml_int64_of_string(value s)
 
 CAMLprim value caml_int64_bits_of_float(value vd)
 {
-  union { double d; int64 i; } u;
+  union { double d; int64 i; int32 h[2]; } u;
   u.d = Double_val(vd);
+#if defined(__arm__) && !defined(__ARM_EABI__)
+  { int32 t = u.h[0]; u.h[0] = u.h[1]; u.h[1] = t; }
+#endif
   return caml_copy_int64(u.i);
 }
 
 CAMLprim value caml_int64_float_of_bits(value vi)
 {
-  union { double d; int64 i; } u;
+  union { double d; int64 i; int32 h[2]; } u;
   u.i = Int64_val(vi);
+#if defined(__arm__) && !defined(__ARM_EABI__)
+  { int32 t = u.h[0]; u.h[0] = u.h[1]; u.h[1] = t; }
+#endif
   return caml_copy_double(u.d);
 }
 
